@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2011 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -331,8 +331,15 @@ builtins. Remember that you should avoid to define new builtins when possible.'
             return
         astmts = [stmt for stmt in node.lookup(name)[1]
                   if hasattr(stmt, 'ass_type')]
-        # filter variables according their respective scope
-        if not astmts or astmts[0].statement().parent_of(node):
+        # filter variables according their respective scope test is_statement
+        # and parent to avoid #74747. This is not a total fix, which would
+        # introduce a mechanism similar to special attribute lookup in
+        # modules. Also, in order to get correct inference in this case, the
+        # scope lookup rules would need to be changed to return the initial
+        # assignment (which does not exist in code per se) as well as any later
+        # modifications.
+        if not astmts or (astmts[0].is_statement or astmts[0].parent) \
+             and astmts[0].statement().parent_of(node):
             _astmts = []
         else:
             _astmts = astmts[:1]
@@ -454,8 +461,9 @@ builtins. Remember that you should avoid to define new builtins when possible.'
     def visit_from(self, node):
         """check modules attribute accesses"""
         name_parts = node.modname.split('.')
+        level = getattr(node, 'level', None)
         try:
-            module = node.root().import_module(name_parts[0])
+            module = node.root().import_module(name_parts[0], level=level)
         except ASTNGBuildingException:
             return
         except Exception, exc:
@@ -482,6 +490,8 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 break
             try:
                 module = module.getattr(name)[0].infer().next()
+                if module is astng.YES:
+                    return None
             except astng.NotFoundError:
                 self.add_message('E0611', args=(name, module.name), node=node)
                 return None
