@@ -126,6 +126,10 @@ class PyLinter(OptionsManagerMixIn, MessagesHandlerMixIn, ReportsHandlerMixIn,
     to:
     * handle message activation / deactivation at the module level
     * handle some basic but necessary stats'data (number of classes, methods...)
+
+    IDE plugins developpers: you may have to call
+    `logilab.astng.builder.MANAGER.astng_cache.clear()` accross run if you want
+    to ensure the latest code version is actually checked.
     """
 
     __implements__ = (ILinter, IRawChecker)
@@ -137,11 +141,10 @@ class PyLinter(OptionsManagerMixIn, MessagesHandlerMixIn, ReportsHandlerMixIn,
     may_be_disabled = False
 
     options = (('ignore',
-                {'type' : 'csv', 'metavar' : '<file>',
+                {'type' : 'csv', 'metavar' : '<file>[,<file>...]',
                  'dest' : 'black_list', 'default' : ('CVS',),
-                 'help' : 'Add <file or directory> to the black list. It \
-should be a base name, not a path. You may set this option multiple times.'}),
-
+                 'help' : 'Add files or directories to the blacklist. \
+They should be base names, not paths.'}),
                ('persistent',
                 {'default': True, 'type' : 'yn', 'metavar' : '<y_or_n>',
                  'level': 1,
@@ -684,6 +687,10 @@ except AttributeError:
     __builtins__['_'] = str
 
 
+class ArgumentPreprocessingError(Exception):
+    """Raised if an error occurs during argument preprocessing."""
+
+
 def preprocess_options(args, search_for):
     """look for some options (keys of <search_for>) which have to be processed
     before others
@@ -703,6 +710,8 @@ def preprocess_options(args, search_for):
                 cb, takearg = search_for[option]
                 del args[i]
                 if takearg and val is None:
+                    if i >= len(args) or args[i].startswith('-'):
+                        raise ArgumentPreprocessingError(arg)
                     val = args[i]
                     del args[i]
                 cb(option, val)
@@ -725,11 +734,16 @@ group are mutually exclusive.'),
     def __init__(self, args, reporter=None, exit=True):
         self._rcfile = None
         self._plugins = []
-        preprocess_options(args, {
-            # option: (callback, takearg)
-            'rcfile':       (self.cb_set_rcfile, True),
-            'load-plugins': (self.cb_add_plugins, True),
-            })
+        try:
+            preprocess_options(args, {
+                # option: (callback, takearg)
+                'rcfile':       (self.cb_set_rcfile, True),
+                'load-plugins': (self.cb_add_plugins, True),
+                })
+        except ArgumentPreprocessingError, e:
+            print >> sys.stderr, 'Argument %s expects a value.' % (e.args[0],)
+            sys.exit(32)
+
         self.linter = linter = self.LinterClass((
             ('rcfile',
              {'action' : 'callback', 'callback' : lambda *args: 1,
