@@ -1,4 +1,4 @@
-# pylint: disable-msg=R0903
+# pylint: disable=R0903
 """Backend Base Classes for the schwelm user DB"""
 
 __revision__ = "alpha"
@@ -7,7 +7,7 @@ class Aaa(object):
     """docstring"""
     def __init__(self):
         self.__setattr__('a','b')
-        pass
+
 
     def one_public(self):
         """docstring"""
