@@ -120,6 +120,12 @@ class NonRegrTC(TestCase):
         got = linter.reporter.finalize().strip()
         self.failUnlessEqual(got, '')
 
+    def test_import_assign_crash(self):
+        linter.check(join(REGR_DATA, 'import_assign.py'))
+
+    def test_special_attr_scope_lookup_crash(self):
+        linter.check(join(REGR_DATA, 'special_attr_scope_lookup_crash.py'))
+
     def test_module_global_crash(self):
         linter.check(join(REGR_DATA, 'module_global.py'))
         got = linter.reporter.finalize().strip()
@@ -139,12 +145,15 @@ class NonRegrTC(TestCase):
     def test_try_finally_disable_msg_crash(self):
         linter.check(join(REGR_DATA, 'try_finally_disable_msg_crash'))
 
-
     def test___path__(self):
         linter.check('pylint.checkers.__init__')
         messages = linter.reporter.finalize().strip()
         self.failIf('__path__' in messages, messages)
 
+    def test_absolute_import(self):
+        linter.check(join(REGR_DATA, 'absimp', 'string.py'))
+        got = linter.reporter.finalize().strip()
+        self.failUnlessEqual(got, "W:  6: Uses of a deprecated module 'string'")
 
 if __name__ == '__main__':
     unittest_main()
